###################################################
### chunk number 1: 
###################################################
library(coxme)
fit1 <- coxme(Surv(time, status) ~ rx + (1 | litter), data=rats)
print(fit1)


###################################################
### chunk number 2: 
###################################################
fit0 <- coxph(Surv(time, status) ~ rx, rats)
print(fit0)


###################################################
### chunk number 3: 
###################################################
profile.x <- matrix(0., nrow=30, ncol=2)
profile.y <- profile.x                    
profile.x[,1] <- seq(.25, 1.6, length=30)
profile.x[,2] <- seq(0.05, 2, length=30)
for (i in 1:30) {
    tfit <- coxme(Surv(time, status) ~ offset(rx * profile.x[i,1]) + 
                         (1|litter), data=rats)
    profile.y[i,1] <- tfit$loglik[2]
    
    tfit <- coxme(Surv(time, status) ~ rx + (1|litter), 
                  data=rats, vfixed=profile.x[i,2])
    profile.y[i,2] <- tfit$loglik[2]
  }
matplot(profile.x, 2*(profile.y - fit0$loglik[1]), xlab="Parameter estimate",
        ylab="Profile likelihood", type='l', lty=1, col=1:2)
abline(h=2*diff(fit1$loglik)[1] - qchisq(.95,1), lty=2)

legend(1.5,9, c("Fixed", "Random"), lty=1, col=1:2)


###################################################
### chunk number 4: 
###################################################
efit0 <- coxph(Surv(y, uncens) ~ trt, eortc)
efit1 <- coxme(Surv(y, uncens) ~ trt + (1|center),
               data=eortc)
efit2 <- coxme(Surv(y, uncens) ~ trt + (1|center) + (trt|center),
               data=eortc)
efit3 <- coxme(Surv(y, uncens) ~ trt + (1+ trt | center), eortc)

2*(c(efit0$loglik[2], efit1$loglik[2], efit2$loglik[2], 
     efit3$loglik[2]) - efit0$loglik[1])


###################################################
### chunk number 5: 
###################################################
coxph(Surv(time, status) ~ ph.ecog, lung)

coxph(Surv(time, status) ~ factor(ph.ecog), lung)


###################################################
### chunk number 6: 
###################################################
ecog0 <- 1*(lung$ph.ecog==0)
ecog1 <- 1*(lung$ph.ecog==1)
ecog2 <- 1*(lung$ph.ecog==2)
ecog3 <- 1*(lung$ph.ecog==3)

sfit <- coxme(Surv(time, status) ~ (ecog0 +ecog1 +ecog2+ ecog3 |1), lung)
print(sfit, rcoef=TRUE)


